// ECMAScript 5 strict mode
"use strict";

assert2(cr, "cr namespace not created");
assert2(cr.plugins_, "cr.plugins_ not created");

/////////////////////////////////////
// Plugin class
cr.plugins_.TapsellSDKV3 = function(runtime)
{
	this.runtime = runtime;
};

(function ()
{

	//////////////////////////////////////
	// TapsellSDKV3
	function TapsellSDKV3(appkey)
	{
		this.onAdAvailable = null;
		this.onNoAdAvailable = null;
		this.onError = null;
		this.onNoNetwork = null;
		this.onExpiring = null;
		this.onOpened = null;
		this.onClosed = null;
		this.onAdShowFinished = null;
		this.onAdShowCanceled = null;
		
		this.zone_to_adId_map = {};

		this.appkey = appkey;
		
		var self = this;
		window['tapsell']['initialize'](this.appkey);
		window['tapsell']['setRewardCallback'](function (result){
			if(result['action']=='onAdShowFinished')
			{
				console.log('showing ad was finished! yay');
				var zone = result['zoneId'];
				var adId = result['adId'];
				var completed = result['completed'];
				var rewarded = result['rewarded'];
				
				console.log('zone found : '+zone);
				console.log('completed? : '+completed);
				console.log('rewarded? : '+rewarded);
				
				if(completed == true)
				{
					console.log('calling self.onAdShowFinished');
					if(self.onAdShowFinished)
					{
						self.onAdShowFinished(zone);
					}
					console.log('self.onAdShowFinished called');
				}
				else
				{
					console.log('calling self.onAdShowCanceled');
					if(self.onAdShowCanceled)
					{
						self.onAdShowCanceled(zone);
					}
				}
			}
		});
		
	};
	
	TapsellSDKV3.prototype.requestAd = function(zoneId, cached)
	{
		console.log('TapsellSDKV3.prototype.requestAd called')
		var self = this;
		window['tapsell']['requestAd'](zoneId, cached, function(result){
			if(result['action']=='onAdAvailable')
			{
				console.log('tapsell sdk called onAdAvailable');
				var zone = result['zoneId']; 
				var adId = result['adId']; // store this to show the ad later
				console.log('ad is available, storing zoneId and adId in map');
				self.zone_to_adId_map[zone]=adId;
				console.log('calling onAdAvailable');
				self.onAdAvailable(zone);
			}
			else if( result['action']=='onNoAdAvailable' )
			{
				console.log('tapsell sdk called onNoAdAvailable');
				var zone = result['zoneId'];
				self.onNoAdAvailable(zone);
			}
			else if( result['action']=='onNoNetwork' )
			{
				console.log('tapsell sdk called onNoNetwork');
				var zone = result['zoneId'];
				self.onNoNetwork(zone);
			}
			else if( result['action']=='onError' )
			{
				console.log('tapsell sdk called onError');
				var zone = result['zoneId'];
				var error = result['error']; // description of error
				self.onError(zone);
			}
			else if(result['action']=='onExpiring')
			{
				console.log('tapsell sdk called onExpiring');
				var zone = result['zoneId'];
				var adId = result['adId'];
				// indicates that this ad cannot be shown anymore, you should 
				// request a new add
				if(self.zone_to_adId_map && TapsellSDKV3.prototype.zone_to_adId_map[zone]==adId)
				{
					delete self.zone_to_adId_map[zone];
				}
				self.onExpiring(zone);
			}
			else if(result['action']=='onOpened')
			{
				console.log('tapsell sdk called onOpened');
				var zone = result['zoneId'];
				var adId = result['adId'];
				// indicates that this ad cannot be shown anymore, you should 
				// request a new add
				self.onOpened(zone);
			}
			else if(result['action']=='onClosed')
			{
				console.log('tapsell sdk called onClosed');
				var zone = result['zoneId'];
				var adId = result['adId'];
				// indicates that this ad cannot be shown anymore, you should 
				// request a new add
				self.onClosed(zone);
			} 
		});
	}
	
	TapsellSDKV3.prototype.showAd = function(disable_back, immersive_mode, rotation_mode, show_dialog, adId)
	{
		console.log('showAd called, adId is '+adId);
	
		window['tapsell']['showAd'](adId, disable_back, immersive_mode, rotation_mode , show_dialog);
	}

	var pluginProto = cr.plugins_.TapsellSDKV3.prototype;
		
	/////////////////////////////////////
	// Object type class
	pluginProto.Type = function(plugin)
	{
		this.plugin = plugin;
		this.runtime = plugin.runtime;
	};

	var typeProto = pluginProto.Type.prototype;
	
	// called on startup for each object type
	typeProto.onCreate = function()
	{
		if(this.runtime.isBlackberry10 || this.runtime.isWindows8App || this.runtime.isWindowsPhone8 || this.runtime.isWindowsPhone81){
			var scripts=document.getElementsByTagName("script");
			var scriptExist=false;
			for(var i=0;i<scripts.length;i++){
				if(scripts[i].src.indexOf("cordova.js")!=-1||scripts[i].src.indexOf("phonegap.js")!=-1){
					scriptExist=true;
					break;
				}
			}
			if(!scriptExist){
				var newScriptTag=document.createElement("script");
				newScriptTag.setAttribute("type","text/javascript");
				newScriptTag.setAttribute("src", "cordova.js");
				document.getElementsByTagName("head")[0].appendChild(newScriptTag);
			}
		}
	};

	/////////////////////////////////////
	// Instance class
	pluginProto.Instance = function(type)
	{
		this.type = type;
		this.runtime = type.runtime;
	};
	
	var instanceProto = pluginProto.Instance.prototype;
	
	// called whenever an instance is created
	instanceProto.onCreate = function()
	{
		if (!(this.runtime.isAndroid || this.runtime.isiOS || this.runtime.isWindowsPhone8 || this.runtime.isWindowsPhone81))
			return;			
		if (typeof window['tapsell'] == 'undefined')
            return;
			
		this.appKey = this.properties[0];

		if (this.runtime.isAndroid && this.appKey == '')
			return;			
			
		this.tapsell_instance = null;

		if (this.runtime.isAndroid || this.runtime.isiOS)
		{
			this.tapsell_instance = new TapsellSDKV3(this.appKey);
		}
		else if (this.runtime.isiOS)
		{
			this.tapsell_instance = new TapsellSDKV3(this.appKey);
		}
		
		var self = this;
		
		if (this.tapsell_instance)
		{
			this.onAdAvailable = null;
			this.onNoAdAvailable = null;
			this.onError = null;
			this.onNoNetwork = null;
			this.onExpiring = null;
			this.onOpened = null;
			this.onClosed = null;
			this.onAdShowFinished = null;
			this.onAdShowCanceled = null;
		
			this.tapsell_instance.onAdAvailable = function (zone)
			{
				self.runtime.trigger(cr.plugins_.TapsellSDKV3.prototype.cnds.onAdAvailable, self);
			};
			this.tapsell_instance.onNoAdAvailable = function ()
			{
				self.runtime.trigger(cr.plugins_.TapsellSDKV3.prototype.cnds.onNoAdAvailable, self);
			};
			this.tapsell_instance.onError = function ()
			{
				self.runtime.trigger(cr.plugins_.TapsellSDKV3.prototype.cnds.onError, self);
			};
			this.tapsell_instance.onNoNetwork = function ()
			{
				self.runtime.trigger(cr.plugins_.TapsellSDKV3.prototype.cnds.onNoNetwork, self);
			};
			this.tapsell_instance.onExpiring = function ()
			{
				self.runtime.trigger(cr.plugins_.TapsellSDKV3.prototype.cnds.onExpiring, self);
			};
			this.tapsell_instance.onOpened = function ()
			{
				self.runtime.trigger(cr.plugins_.TapsellSDKV3.prototype.cnds.onOpened, self);
			};
			this.tapsell_instance.onClosed = function ()
			{
				self.runtime.trigger(cr.plugins_.TapsellSDKV3.prototype.cnds.onClosed, self);
			};
			this.tapsell_instance.onAdShowFinished = function ()
			{
				self.runtime.trigger(cr.plugins_.TapsellSDKV3.prototype.cnds.onAdShowFinished, self);
			};
			this.tapsell_instance.onAdShowCanceled = function ()
			{
				self.runtime.trigger(cr.plugins_.TapsellSDKV3.prototype.cnds.onAdShowCanceled, self);
			};
			
		}	
	};
	
	instanceProto.draw = function(ctx)
	{
	};
	instanceProto.drawGL = function (glw)
	{
	};

	//////////////////////////////////////
	// Conditions
	function Cnds() {};
	
	Cnds.prototype.onAdAvailable = function ()
	{
		return true;
	};
	Cnds.prototype.onNoAdAvailable = function ()
	{
		return true;
	};
	Cnds.prototype.onError = function ()
	{
		return true;
	};
	Cnds.prototype.onNoNetwork = function ()
	{
		return true;
	};
	Cnds.prototype.onExpiring = function ()
	{
		return true;
	};
	Cnds.prototype.onAdShowFinished = function ()
	{
		return true;
	};
	Cnds.prototype.onAdShowCanceled = function ()
	{
		return true;
	};
	Cnds.prototype.onOpened = function ()
	{
		return true;
	};
	Cnds.prototype.onClosed = function ()
	{
		return true;
	};
	
	pluginProto.cnds = new Cnds();
	
	//////////////////////////////////////
	// Actions
	function Acts() {};
	
	Acts.prototype.requestAd = function(cached, zoneId)
	{
		console.log('Acts.prototype.requestAd called')
		console.log('cached: '+cached)
		console.log('zoneId: '+zoneId)
		if (!(this.runtime.isAndroid))
			return;
		if (typeof window['tapsell'] == 'undefined')
            return;
		if (this.appKey == '')
			return;
		var is_cached = false;
		if(cached==0)
		{
			is_cached = true;
		}
		this.tapsell_instance.requestAd(zoneId, is_cached);
	}
	
	Acts.prototype.showAd = function(back_enabled, immersive_mode, rotation_mode, warning_dialog, zoneId)
	{
		console.log('showAd action called, zoneId is '+zoneId);
		console.log('showAd action called, appKey is '+this.appKey);
		console.log('adId for zone: '+this.tapsell_instance.zone_to_adId_map[zoneId]);
	
		if (!(this.runtime.isAndroid))
			return;
		if (typeof window['tapsell'] == 'undefined')
            return;
		if (this.appKey == '')
			return;
		if(!this.tapsell_instance)
			return;
		if(!this.tapsell_instance.zone_to_adId_map)
			return;
		if(!this.tapsell_instance.zone_to_adId_map[zoneId])
			return;
		var adId = this.tapsell_instance.zone_to_adId_map[zoneId]
		
		var is_back_disabled = true;
		if(back_enabled==0)
		{
			is_back_disabled = false;
		}
		
		var is_immersive_mode = false;
		if(immersive_mode==0)
		{
			is_immersive_mode = true;
		}
		
		var is_warning_dialog_enabled = false;
		if(warning_dialog==0)
		{
			is_warning_dialog_enabled = true;
		}
		
		console.log(zoneId)
		this.tapsell_instance.showAd(is_back_disabled, is_immersive_mode, rotation_mode, is_warning_dialog_enabled, adId);
	}
	
	pluginProto.acts = new Acts();
	
	//////////////////////////////////////
	// Expressions
	function Exps() {};
	
	pluginProto.exps = new Exps();

}());